aiocarbon
=========

.. image:: https://coveralls.io/repos/github/mosquito/aiocarbon/badge.svg?branch=master
    :target: https://coveralls.io/github/mosquito/aiocarbon
    :alt: Coveralls

.. image:: https://travis-ci.org/mosquito/aiocarbon.svg
    :target: https://travis-ci.org/mosquito/aiocarbon
    :alt: Travis CI

.. image:: https://img.shields.io/pypi/v/aiocarbon.svg
    :target: https://pypi.python.org/pypi/aiocarbon/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/wheel/aiocarbon.svg
    :target: https://pypi.python.org/pypi/aiocarbon/

.. image:: https://img.shields.io/pypi/pyversions/aiocarbon.svg
    :target: https://pypi.python.org/pypi/aiocarbon/

.. image:: https://img.shields.io/pypi/l/aiocarbon.svg
    :target: https://pypi.python.org/pypi/aiocarbon/

